/*******************************************************************************
* File Name: Analog_RY.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Analog_RY.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 Analog_RY__PORT == 15 && ((Analog_RY__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: Analog_RY_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void Analog_RY_Write(uint8 value) 
{
    uint8 staticBits = (Analog_RY_DR & (uint8)(~Analog_RY_MASK));
    Analog_RY_DR = staticBits | ((uint8)(value << Analog_RY_SHIFT) & Analog_RY_MASK);
}


/*******************************************************************************
* Function Name: Analog_RY_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Analog_RY_DM_STRONG     Strong Drive 
*  Analog_RY_DM_OD_HI      Open Drain, Drives High 
*  Analog_RY_DM_OD_LO      Open Drain, Drives Low 
*  Analog_RY_DM_RES_UP     Resistive Pull Up 
*  Analog_RY_DM_RES_DWN    Resistive Pull Down 
*  Analog_RY_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Analog_RY_DM_DIG_HIZ    High Impedance Digital 
*  Analog_RY_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Analog_RY_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Analog_RY_0, mode);
}


/*******************************************************************************
* Function Name: Analog_RY_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Analog_RY_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Analog_RY_Read(void) 
{
    return (Analog_RY_PS & Analog_RY_MASK) >> Analog_RY_SHIFT;
}


/*******************************************************************************
* Function Name: Analog_RY_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Analog_RY_ReadDataReg(void) 
{
    return (Analog_RY_DR & Analog_RY_MASK) >> Analog_RY_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Analog_RY_INTSTAT) 

    /*******************************************************************************
    * Function Name: Analog_RY_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Analog_RY_ClearInterrupt(void) 
    {
        return (Analog_RY_INTSTAT & Analog_RY_MASK) >> Analog_RY_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
